==> dolfin-0.4.1.tar.gz: dolfin-0.4.1/src/kernel/ode/SimpleTimeSlab.cpp <==
// Copyright (C) 2003 Johan Hoffman and Anders Logg.
// Licensed under the GNU GPL Version 2.

#include <iostream>

#include <dolfin/dolfin_log.h>
#include <dolfin/Element.h>
#include <dolfin/TimeSteppingData.h>
#include <dolfin/Partition.h>
#include <dolfin/RHS.h>
#include <dolfin/SimpleTimeSlab.h>

using namespace dolfin;

//-----------------------------------------------------------------------------
SimpleTimeSlab::SimpleTimeSlab(real t0, real t1, RHS& f, 
			       TimeSteppingData& data) : TimeSlab(t0, t1)
{
  create(f, data);
}
//-----------------------------------------------------------------------------
SimpleTimeSlab::~SimpleTimeSlab()
{
  // Do nothing
}
//-----------------------------------------------------------------------------
void SimpleTimeSlab::update(RHS& f, TimeSteppingData& data)
{
  updateElements(f, data);
}
//-----------------------------------------------------------------------------
void SimpleTimeSlab::create(RHS& f, TimeSteppingData& data)
{
  dolfin_debug("Creating simple time slab");

  // FIXME: choose element and order here
  Element::Type type = Element::cg;
  int q = 1;

  // Get initial time step (same for all components)
  real k = data.regulator(0).timestep();

  // Set size of this time slab
  setsize(k, data);

  // Create elements
  for (unsigned int i = 0; i < data.size(); i++)
  {
    // Create element
    Element *element = data.createElement(type, t0, t1, q, i);
    
    // Write debug info
    data.debug(*element, TimeSteppingData::create);

    // Add element to array
    elements.push_back(element);
  }
}
//-----------------------------------------------------------------------------

==> dolfin-0.4.2.tar.gz: dolfin-0.4.2/src/kernel/ode/SimpleTimeSlab.cpp <==
// Copyright (C) 2003 Johan Hoffman and Anders Logg.
// Licensed under the GNU GPL Version 2.

#include <iostream>

#include <dolfin/dolfin_log.h>
#include <dolfin/Element.h>
#include <dolfin/Adaptivity.h>
#include <dolfin/RHS.h>
#include <dolfin/Solution.h>
#include <dolfin/SimpleTimeSlab.h>

using namespace dolfin;

//-----------------------------------------------------------------------------
SimpleTimeSlab::SimpleTimeSlab(real t0, real t1, Solution& u, 
			       Adaptivity& adaptivity) : TimeSlab(t0, t1)
{
  create(u, adaptivity);
}
//-----------------------------------------------------------------------------
SimpleTimeSlab::~SimpleTimeSlab()
{
  // Do nothing
}
//-----------------------------------------------------------------------------
void SimpleTimeSlab::update(Solution& u, RHS& f)
{
  updateElements(u, f);
}
//-----------------------------------------------------------------------------
void SimpleTimeSlab::create(Solution& u, Adaptivity& adaptivity)
{
  // FIXME: choose element and order here
  Element::Type type = Element::cg;
  int q = 1;

  // Get initial time step (same for all components)
  real k = adaptivity.regulator(0).timestep();

  // Set size of this time slab
  setsize(k, adaptivity);

  // Create elements
  for (unsigned int i = 0; i < u.size(); i++)
  {
    // Create element
    Element *element = u.createElement(type, q, i, t0, t1);
    
    // Write debug info
    u.debug(*element, Solution::create);

    // Add element to array
    elements.push_back(element);
  }
}
//-----------------------------------------------------------------------------
